select
       event.m_type,
       prforigin.m_time_value + (prforigin.m_time_value_ms || ' microseconds')::interval as sourcetime,
       round(prforigin.m_latitude_value::numeric, 5)                             as lat,
       round(prforigin.m_longitude_value::numeric, 5)                            as lon,
       round(prforigin.m_depth_value::numeric, 1)                                as dep,
       --round(prforigin.m_uncertainty_azimuthmaxhorizontaluncertainty::numeric,1) as herr_azi,
       --round(prforigin.m_uncertainty_maxhorizontaluncertainty::numeric,1)        as herr_max,
       --round(prforigin.m_uncertainty_minhorizontaluncertainty::numeric,1)        as herr_min,
       --round(prforigin.m_depth_uncertainty::numeric,1)                           as dep_err,
       round(magnitude.m_magnitude_value::numeric,2)                             as mag_median,
       magnitude.m_type                                                          as mag_type,
       
       -- [OPTION] All magnitude infos
       --magnitude.*,
       
       prforigin.m_evaluationmode,
       eventdescription.m_text,
       prforigin.m_creationinfo_agencyid,
       prforigin.m_creationinfo_author

       -- [OPTION] timestamp of last modification
       --prforigin._last_modified

       -- [OPTION] count the number of stations used for automatic magnitude]
       --SUM(CASE WHEN anyorigin.m_evaluationmode = 'automatic' THEN 1 ELSE 0 END) as auto_cnt
       
--       -- [OPTION] calc horizontal distance to point
--       ST_Distance (
--         ST_GeographyFromText('SRID=4326; POINT(' || prforigin.m_longitude_value || '
--                                                ' || prforigin.m_latitude_value  || ') '),
--         ST_GeographyFromText('SRID=4326; POINT(7.593662 47.586091)')

--       -- [OPTION] 3d distance to point
--       power(power(ST_Distance(
--         ST_GeographyFromText('SRID=4326; POINT(' || prforigin.m_longitude_value || '
--                                                ' || prforigin.m_latitude_value  || ') '),
--         ST_GeographyFromText('SRID=4326; POINT(7.593662 47.586091)')
--        ) / 1000, 2) + power(prforigin.m_depth_value - 4.4, 2), 0.5) as dist_km_3d

       -- [OPTION] Pick info
       --pick.m_waveformid_stationcode as stationcode,
       --arrival.m_phase_code as phase,
       --pick.m_time_value + (pick.m_time_value_ms || ' microseconds')::interval as picktime

from
       -- FYI: the order of INNER joins doesn't matter

       event inner join origin as prforigin on prforigin.m_publicid         = event.m_preferredoriginid
             
             -- [OPTION] For counting the number of stations used for automatic magnitude
             --inner join originreference     on originreference._parent_oid  = event._oid
             --inner join origin as anyorigin on anyorigin.m_publicid         = originreference.m_originid
             
             -- [OPTION] Magnitude info: preferred one (first line) or all (last two lines)
             inner join magnitude           on magnitude.m_publicid         = event.m_preferredmagnitudeid  -- Only preferred magnitude
             --inner join origin              on event.m_preferredoriginid    = origin.m_publicid  -- All magnitude types
             --inner join magnitude           on magnitude._parent_oid        = origin._oid        -- All magnitude types
             
             left join eventdescription     on eventdescription._parent_oid = event._oid
             
             -- [OPTION] Pick times
             --inner join arrival             on arrival._parent_oid          = prforigin._oid
             --inner join pick                on arrival.m_pickid             = pick.m_publicid

where  
       --(eventdescription.m_text ~ 'BASEL' or eventdescription.m_text ~ 'Basel')
       
       ST_Distance (
         ST_GeographyFromText('SRID=4326; POINT(' || prforigin.m_longitude_value || '
                                                ' || prforigin.m_latitude_value  || ') '),
         ST_GeographyFromText('SRID=4326; POINT(7.593662 47.586091)')
        ) /1000 <= 2.5  -- horizontal distance from point [km]
        
       --and (prforigin.m_latitude_value  >= 47.5 and prforigin.m_latitude_value  <= 47.7)
       --and (prforigin.m_longitude_value >= 7.45  and prforigin.m_longitude_value <= 7.7)

       and (prforigin.m_depth_value < 15)

       --and (event.m_type = 'earthquake' or event.m_type = '' or event.m_type is null)  -- Limit to only earthquakes
       --and (event.m_type = 'earthquake' or (event.m_type = 'outside' and prforigin.m_creationinfo_agencyid = 'SED_MuAn') -- Toni's special category
       
       --and prforigin.m_time_value > '2006-12-01 00:00:00'::timestamp
       
       -- [OPTION] when having pick info
       --and pick.m_waveformid_stationcode = 'OTER2' and arrival.m_phase_code ~ 'P'

--group by
--       event.m_type,
--       prforigin.m_time_value,
--       prforigin.m_time_value + (prforigin.m_time_value_ms || ' microseconds')::interval, 
--       prforigin.m_latitude_value, 
--       prforigin.m_longitude_value, 
--       prforigin.m_depth_value,
--       --prforigin.m_uncertainty_azimuthmaxhorizontaluncertainty,
--       --prforigin.m_uncertainty_maxhorizontaluncertainty,
--       --prforigin.m_uncertainty_minhorizontaluncertainty,
--       prforigin.m_depth_uncertainty,
--       prforigin.m_evaluationmode,     
--       magnitude.m_magnitude_value,
--       magnitude.m_type,
--       --magnitude._oid,  -- All magnitude infos
--       eventdescription.m_text,
--       prforigin.m_creationinfo_agencyid,
--       prforigin.m_creationinfo_author,
--       --prforigin._last_modified,
--       --pick.m_waveformid_stationcode,
--       --arrival.m_phase_code,
--       --pick.m_time_value
--       --pick.m_time_value_ms

--having SUM(CASE WHEN anyorigin.m_evaluationmode = 'automatic' THEN 1 ELSE 0 END) > 0

order by
       prforigin.m_time_value asc;
       --prforigin.m_time_value, pick.m_time_value;

