import copy
from sequential_loader import SequentialLoader

class Chunks(object):
    """
    A map of the chunks we devide the data into
    """    
    def __init__(self, start_date, end_date, chunk_len, overlap_len):
        self.start_date  = copy.copy(start_date)
        self.end_date    = copy.copy(end_date)
        self.chunk_len   = chunk_len
        self.overlap_len = overlap_len
        #
        # build chunk tables
        #
        self.chunk_table = {}
        currtime = copy.copy(self.start_date)        
        id = 0
        while currtime < self.end_date:
            endtime = currtime + chunk_len + overlap_len
            if endtime > self.end_date:
                endtime = self.end_date
            length  = endtime - currtime
            self.chunk_table[id] = (currtime, endtime, length)
            currtime += chunk_len
            id += 1

    def get(self, id):
        return self.chunk_table[id] # (start, end, length)

    def print(self):
        for id in sorted(self.chunk_table.keys()):
            start, end, length = self.chunk_table[id]
            print("chunk id %4d start %s end %s length %d" % (id, start, end, length))
                
class ChunkManager(SequentialLoader):
    """
    Keep track of loaded chunks from archive to filesystem.
    The maximum loaded chunks must not exceed 'window_len' at any given time
    """                
    def __init__(self, chunks, window_len):
        self.chunks  = chunks
        self.window_len = window_len
        super(ChunkManager, self).__init__( sorted(self.chunks.chunk_table.keys()) )
  
    def window_full(self):
        # make sure we don't have more than windows_len chunks
        return (len(self.loaded) + len(self.loading)) >= self.window_len
                
    def is_next_available(self):
        if self.window_full():
            return False
        return super(ChunkManager, self).is_next_available()
        
    def get_next(self):
        if self.window_full():
            return None
        return super(ChunkManager, self).get_next()
        
    def set_unloadable(self, id):
        self.remove(id)
