from mpi4py import MPI
from tm_master_slave import TMSlave
from template_matching import TemplateMatching
import sys

def run_mpi(config, template_set=None, catalog=None):
    """
    This is the main entry point of the template matching application

    Only the master will return from this function, the slaves will exit
    """

    name = MPI.Get_processor_name()
    rank = MPI.COMM_WORLD.Get_rank()
    size = MPI.COMM_WORLD.Get_size()

    print('I am  %s rank %d (total %d)' % (name, rank, size) )

    if rank == 0: # Master

        if not template_set and catalog:
            # Let the first template be large enough
            firstEvent = [x for x in catalog if x[1] >= config.firstTemplateMinMag][0]
            template_set = [[firstEvent[0], 0.0, config.duration, firstEvent[1]]]
            print("Taking %s (M%.1f) as the initial template." % (firstEvent[0], firstEvent[1]))

        master = TemplateMatching(config, template_set, catalog, slaves=range(1, size))
        master.run()
        master.terminate_slaves()

        return (master.events, master.template_mngr.get_templates())

    else: # Any slave

        TMSlave(config).run()
        sys.exit(0)

    print('Task completed (rank %d)!' % (rank) )
