

class ScannedDaysManager(object):
    """
    Keep track of which chunk have already been processed by which template
    """
    def __init__(self):
        self.templates  = set()
        self.chunks     = set()
        self.to_process = {}
        self.processing = {}
        self.processed  = {}

    def __add_entry(self, container, chunk, template):
        new_set = container.get(chunk, set())
        new_set.add(template)
        container[chunk] = new_set

    def __remove_entry(self, container, chunk, template):
        if chunk in container:
            templates = container[chunk]
            templates.remove(template)
            if not templates:
                del container[chunk]

    def __filterset(self, myset, myfilter):
        return set(myset) if myfilter is None else set(myfilter) & myset

    def add_chunk_to_process(self, chunk):
        if chunk not in self.chunks:
            self.chunks.add(chunk)
            if self.templates:
                self.to_process[chunk] = set(self.templates)

    def add_template_to_process(self, template):
        if template not in self.templates:
            self.templates.add(template)
            for chunk in self.chunks:
                _set = self.to_process.get(chunk, set())
                _set.add(template)
                self.to_process[chunk] = _set

    def done(self, chunks_to_consider = None):
        chunk_to_process = self.__filterset(self.to_process.keys(), chunks_to_consider)
        chunk_processing = self.__filterset(self.processing.keys(), chunks_to_consider)
        return (not chunk_to_process) and (not chunk_processing)

    def is_next_available(self, chunks_to_consider = None):
        chunk_to_process = self.__filterset(self.to_process.keys(), chunks_to_consider)
        return bool(chunk_to_process)

    def next_to_process(self, chunks_to_consider = None):
        chunk_to_process = self.__filterset(self.to_process.keys(), chunks_to_consider)
        for chunk in sorted(chunk_to_process):
            template = next(iter( self.to_process[chunk] ))
            self.__remove_entry(self.to_process, chunk, template)
            self.__add_entry(self.processing, chunk, template)
            return (chunk, template)
        return (None, None)

    def set_processed(self, chunk, template):
        if chunk in self.processing:
            self.__remove_entry(self.processing, chunk, template)
            self.__add_entry(self.processed, chunk, template)

    def set_to_process(self, chunk, template):
        if chunk in self.processing:
            self.__remove_entry(self.processing, chunk, template)
            self.__add_entry(self.to_process, chunk, template)
