

class SequentialLoader(object):
    """
    Load 'to_load' one by one and keep track of what done and what to do
    """
    def __init__(self, to_load):
        self.to_load = list(to_load)
        self.loading = set()
        self.loaded  = list()

    def done(self):
        return (not self.to_load) and (not self.loading)

    def is_next_available(self):
        return bool(self.to_load)

    def get_next(self):
        next = None
        if self.to_load:
            next = self.to_load.pop(0)
            self.loading.add(next)
        return next

    def set_loaded(self, id):
        if id in self.loading:
            self.loading.remove(id)
            self.loaded.append(id)

    def set_to_load(self, id):
        if id in self.loading:
            self.loading.remove(id)
            self.to_load.insert(0, id)

    def add_to_load(self, id):
        if id not in self.to_load: self.to_load.append(id)
        if id in self.loading:     self.loading.remove(id)
        if id in self.loaded:      self.loaded.remove(id)

    def remove(self, id):
        if id in self.to_load: self.to_load.remove(id)
        if id in self.loading: self.loading.remove(id)
        if id in self.loaded:  self.loaded.remove(id)
