from sequential_loader import SequentialLoader

class TemplateManager(SequentialLoader):
    """
    Keep track of loaded templates from archive to filesystem
    """
    def __init__(self, template_set):
        if template_set is None:
            template_set = []
        self.map = { id:template for id, template in enumerate(template_set) }
        self.starting_length = len(self.map)
        to_load = sorted( self.map.keys() )
        super(TemplateManager, self).__init__(to_load)

    def add_template(self, template):
        next_id = max(self.map) + 1 if self.map else 0
        self.map[next_id] = template
        self.add_to_load(next_id)

    def get_template(self, template):
        return self.map[template]

    def get_templates(self):
        return [self.map[i] for i in sorted(self.map)]

    def set_unloadable(self, template):
        self.remove(template)
