from lru_cache import LRUCache
import TM.io as tmio
import TM.core as tmcore

class TemplateMatchingTasks(object):
    """
    Slave of template matching application. It performs unit tasks in a
    separate process (there are actually many of these)  and it is controlled
    by the main template matching class
    """
    def __init__(self, cache_size=20):
        self.template_cache = LRUCache(capacity=cache_size)
        self.chunk_cache = LRUCache(capacity=1)  # too big to have a cache of chunks

    def preload_template(self, id, time, length, magnitude):
        template, shift = tmio.preload_template(id, time, length, magnitude)
        if template is None:
            return (id, True)
        # The templateSet should be updated with the new 'shift' value (not important for now)
        self.template_cache.set(id, template)
        return (id, False)

    def __read_template(self, id):
        template = tmio.read_template(id)
        if template is not None:
            self.template_cache.set(id, template)
        return template

    def preload_chunk(self, id, time, length):

        chunk, stdWind = tmio.preload_chunk(id, time, length)
        if chunk is None or stdWind is None:
            return (id, True)
        self.chunk_cache.set(id, (chunk, stdWind) )
        return (id, False)

    def __read_chunk(self, id):
        chunk, stdWind = tmio.read_chunk(id)
        if chunk is not None and stdWind is not None:
            self.chunk_cache.set(id, (chunk, stdWind) )
        return chunk, stdWind

    def xcorr_chunk(self, template_id, chunk_id):

        # load template
        template = self.template_cache.get(template_id)
        if template is None:
            template = self.__read_template(template_id)

        # load chunk
        cached_chunk = self.chunk_cache.get(chunk_id)
        if cached_chunk is not None:
            chunk, stdWind = cached_chunk
        else:
            chunk, stdWind = self.__read_chunk(chunk_id)

        if chunk is None or stdWind is None or template is None:
            return (chunk_id, template_id, None)

        # x_corr
        xcorr_results = tmcore.do_xcorr_onetemplate(chunk, template, stdWind)
        return (chunk_id, template_id, xcorr_results)
