from master_slave import Master, Slave
from template_matching_tasks import TemplateMatchingTasks
from mpi4py import MPI
from enum import IntEnum

Tasks = IntEnum('Tasks', 'LOAD_TEMPLATE LOAD_CHUNK XCORR_CHUNK')

class TMMaster(Master):
    
    def __init__(self, task, tm_slaves = None):
        super(TMMaster, self).__init__(tm_slaves)
        self.task = task

    def run(self, tm_slave, data):
        args = (self.task, data)
        super(TMMaster, self).run(tm_slave, args)
        
class TMSlave(Slave):
    
    def __init__(self, config):
        super(TMSlave, self).__init__()
        self.config = config
        self.task = TemplateMatchingTasks()
        
    def do_work(self, args):
        task, data = args
        
        rank = MPI.COMM_WORLD.Get_rank()
        name = MPI.Get_processor_name()
                
        ret = None
        if task == Tasks.LOAD_TEMPLATE:
            
            template, time, length, magnitude = data
            print('  TMSlave task %s %s rank %d: template %d (time %s length %s magnitude %s)' %
                  (task, name, rank, template, time, length, magnitude) )
            ret = self.task.preload_template(template, time, length, magnitude)
            
        elif task == Tasks.LOAD_CHUNK:
            
            chunk, time, length = data            
            print('  TMSlave task %s %s rank %d: chunk %d (time %s length %s)' %
                 (task, name, rank, chunk, time, length) )
            ret = self.task.preload_chunk(chunk, time, length)
            
        elif task == Tasks.XCORR_CHUNK:
            
            chunk, template = data
            print('  TMSlave task %s %s rank %d: chunk %d template %d' %
                 (task, name, rank, chunk, template) )
            ret = self.task.xcorr_chunk(template, chunk)
            
        print('  Done (return %s)' % str(ret))
        
        return ret
