# -*- coding: utf-8 -*-
"""
Script to display a waveform


(created) 2015, Marcus Herrmann, Swiss Seismological Service, ETH Zürich
"""

import datetime
from multiprocessing.pool import ThreadPool

from itertools import repeat

from obspy import UTCDateTime
from obspy.core import read, Stream
from obspy.clients.fdsn.client import Client as clientFDSN
#from obspy.clients.arclink.client import Client as clientArcLink

# --- Loading option 1: Using existing functions

import sys
import os
sys.path.insert(0, os.path.abspath('..'))  # Give the location of the "TM app"

from TM.setupclass import config  # Setup class (this also makes an instance)
from TM.io import get_waveform, get_waveform_SDS, get_waveform_FDSN


# --- Loading option 2: this functions (for experimenting / debugging)

## [using FDSN]
#def get_waveform(network, station, channel, t, duration):
#    """Returns a waveform for specified parameters using FDSN"""
#
#    # Specify FDSN client
#    client = clientFDSN(config.FDSN_server)
##    client = clientArcLink(user='sc31007arc', host='arclink.ethz.ch')
#
#    starttime = t-1
#    endtime = t + duration + 1
#
#    # Make request
#    request = [network, station, "*", channel, starttime, endtime]
#    try:
#        stream = clientFDSN.get_waveforms(*request)
#
#        print(stream)
#
#        stream.merge(fill_value=None)
#
#        # Get the one (and only) trace object
#        trace = stream[0]
#
#    except Exception as err:
#        raise Exception("Date could not be read. ", err)
#
#    # Make sure to get the appropriate time range (FDSN may return more data)
#    trace.trim(starttime, endtime)
#
#    return trace
#
## [using a mounted MSEED archive]
#def get_waveform(network, station, channel, t, duration):
#    """Returns a waveforms for specified parameters using a mounted seed archive"""
#
##    network = "CH"
##    station = "OTER2"
##    channel = "DP1"
##    t = UTCDateTime("2006-12-05T03:04:39")
##    t = UTCDateTime("2007-01-25T03:04:39")
##    duration = 3600
#
#    localPath = "/mnt/SED-miniseed/"
#    year = UTCDateTime(t).year
#    julday = UTCDateTime(t).julday
#
#    # Specify file
#    mseed_file = localPath + str(year) + "/" + network + "/" + station + "/" + \
#        channel + ".D/*." + str(julday).zfill(3)
#
#    # Read the file
#    try:
#        stream = read(mseed_file, starttime=t-1, endtime=t+duration+2)
##        stream = read(mseed_file)
##        stream.trim(starttime=t-1, endtime=t+duration+1)
#
#        print(stream)
#
#        stream.merge(fill_value=None)
##        stream.merge(fill_value=0)
#
#        # Get the one (and only) trace object
#        trace = stream[0]
#
#    except Exception as err:
#        raise Exception("File not found", err)
#    else:
#        pass
#
#    return trace

# --- Parameters

# Use FDSN as data source?
#config.FDSN = True
#config.FDSN_server = 'http://arclink.ethz.ch'
#config.FDSN_server = 'ETH'
#config.FDSN_server = 'GFZ'

config.mseedDir = '/mnt/SED-miniseed/'  # Location of the MSEED archive
config.filterBuff = 1.0                 # Pre-and append some time
config.use_threads = True               # Parallel reading

config.network = "CH"
#config.station = "HALTI"; config.channels = ["DP1"]
#config.station = "OTER2"; config.channels = ["DP1", "DP2", "DP3"]
#config.station = "OTER2"; config.channels = ["EHZ", "EH2", "EH3"]
#config.station = "MATTE"; config.channels = ["DP1", "DP2", "DP3"]
config.station = "MATTE"; config.channels = ["EHA", "EHB", "EHC"]
#config.station = "ZUR"; config.channels = ["HHZ", "HHN", "HHE"]
t = UTCDateTime("2006-12-01T22:00:00.000000") - 0.0
#t = UTCDateTime(datetime.datetime.utcnow()) - 3600.0   # Now minus one hour
#t = UTCDateTime(datetime.datetime.now().date())        # Last midnight

duration = 1*60
#duration = 86400 # One day


# --- Reading

if config.use_threads:
    # Read files in parallel using threads
    with ThreadPool(config.numChannels) as pool:
        stream = Stream(pool.starmap(
             get_waveform, zip(repeat(config.network), repeat(config.station),
                               config.channels, repeat(t), repeat(duration))))
else:
    # Read in serial
    stream = Stream()
    for chnl in config.channels:
        # Derive waveform
        stream += get_waveform(config.network, config.station, chnl, t, duration)

# Read a particular file
#stream = read('D:\Downloads\CH.OTER2..DP1.D.2006.336')
#stream.merge(fill_value=None)

#print(waveform)


# --- Plotting

#stream.plot()
#stream.plot(reftime=t+0, type='relative')

stream.detrend()

#stream.plot()
stream.copy().filter('highpass', freq=0.1).plot()
#stream.copy().filter("bandpass", freqmin=5.0, freqmax=30.0).plot()


#  Save plot
#stream.plot(outfile='%s.%s_' % (network, station) + 
#                    str(t).replace(":", "-") + '_%ds' % duration +
#                    '.png')
