#!/bin/sh
# Plot catalog locations (and mark templates)
# 
#source ~/.alias
#shopt -s expand_aliases

Region=$1
DIR=$2

out=$DIR/"locations_"$1

numTEMPLATES=$3

## GMT settings
gmt set PS_MEDIA a2
gmt set PS_PAGE_ORIENTATION landscape

gmt set MAP_FRAME_TYPE fancy+
gmt set MAP_DEFAULT_PEN black
gmt set FORMAT_GEO_MAP +D.
gmt set MAP_FRAME_WIDTH 3p

gmt set MAP_GRID_PEN_PRIMARY 0.1p

gmt set FONT_LABEL 12
gmt set FONT_ANNOT_PRIMARY 8
gmt set MAP_ANNOT_OFFSET_PRIMARY 2p
gmt set MAP_LABEL_OFFSET 4p

# Make colormap
COLORMAP=colormap.cpt
COLORTABLE=panoply  # panoply, rainbow, jet, cyclic, haxby, wysiwyg
gmt makecpt -C$COLORTABLE --COLOR_BACKGROUND=lightgray -T1/`echo $numTEMPLATES | awk '{print $1*1+1}'`/1 > $COLORMAP

###################### MAP VIEW
# For a constant dimensions among sequences
#R=$(gmt gmtinfo -C $DIR/loc_catalog.dat | awk '{print "-R"$3+($4-$3)/2-0.035"/"$3+($4-$3)/2+0.035"/"$5+($6-$5)/2-0.025"/"$5+($6-$5)/2+0.025}')
# For an individual (tight) plot
R=$(awk '{print $2, $3, 0.01, 0.01}' $DIR/loc_catalog.dat | gmt gmtinfo -Sxy -I0.0001)

#gmt psbasemap -JM320p $R -B0.05g0.01:"":/0.05g0.01:"":WnSe -K -P > $out.ps
gmt psbasemap -JM240ph $R -B0.01g0.01WnSe -K -P > $out.ps

# 1. the catalog events
awk '$0!~/#/ {mag=$5; {if (mag < 0.1)mag=0.1} print $2, $3, mag^1}' $DIR/loc_catalog.dat |\
	sort -k3nr |\
	gmt psxy -R -J -Sc -Wthinnest,black -G100 -O -K >> $out.ps
# 1.1 the catalog events with the associated template (i.e. only found events above threshold)
awk '$0!~/#/ {mag=$5; {if (mag < 0.1)mag=0.1} print $2, $3, $(NF-1), mag^1}' $DIR/loc_catalog_assoc.dat |\
	sort -k4nr |\
	gmt psxy -R -J -Sc -Wthinnest,black -C$COLORMAP -O -K >> $out.ps
# (sorting to plot the smaller over the bigger)

# 2. the templates
awk '$0!~/#/ {mag=$5; {if (mag < 0.1)mag=0.1} print $2, $3, $NF, mag^1}' $DIR/loc_templateSet.dat |\
	sort -k4nr |\
	gmt psxy -R -J -Sc -Wthick,black -C$COLORMAP -O -K >> $out.ps
awk '{print $2, $3, 14, 0, 0, "CM", NR}' $DIR/loc_templateSet.dat |\
	gmt pstext -R -J -V -O -K >> $out.ps


###################### DEPTH-NORTHING VIEW
# For a constant dimensions among sequences
#R=$(gmt gmtinfo -C $DIR/loc_catalog.dat | awk '{print "-R"$7-1"/"$8+1"/"$5+($6-$5)/2-0.019"/"$5+($6-$5)/2+0.019}')
# For an individual (tight) plot
R=$(awk '{print $4, $3, 1, 0.01}' $DIR/loc_catalog.dat | gmt gmtinfo -Sxy -I0.0001)
Xshift=$(awk '{print $2, $3, 0.01, 0.01}' $DIR/loc_catalog.dat | gmt gmtinfo -C -Sxy | awk '{print int(($2-$1)/($4-$3)*240*0.75)"p"}')

gmt psbasemap -JX240ph $R -B1g1:"Depth":/0.01g0.01wnSE -X$Xshift -O -K -P >> $out.ps

# 1. the catalog events
awk '$0!~/#/ {mag=$5; {if (mag < 0.1)mag=0.1} print $4, $3, mag^1}' $DIR/loc_catalog.dat |\
	sort -k3nr |\
	gmt psxy -R -J -Sc -Wthinnest,black -G100 -O -K >> $out.ps
# 1.1 the catalog events with the associated template (i.e. only found events above threshold)
awk '$0!~/#/ {mag=$5; {if (mag < 0.1)mag=0.1} print $4, $3, $(NF-1), mag^1}' $DIR/loc_catalog_assoc.dat |\
	sort -k4nr |\
	gmt psxy -R -J -Sc -Wthinnest,black -C$COLORMAP -O -K >> $out.ps
# (sorting to plot the smaller over the bigger)

# 2. the templates
# (circled in thick black)
awk '$0!~/#/ {mag=$5; {if (mag < 0.1)mag=0.1} print $4, $3, $NF, mag^1}' $DIR/loc_templateSet.dat |\
	sort -k4nr |\
	gmt psxy -R -J -Sc -Wthick,black -C$COLORMAP -O -K >> $out.ps
# (numbered)
awk '{print $4, $3, 14, 0, 0, "CM", NR}' $DIR/loc_templateSet.dat |\
	gmt pstext -R -J -V -O -K >> $out.ps


# Legend
legXshift=280p
legYshift=0
legHeight=240p
psbasemap -R0/1/0/1 -JX2.5/$legHeight -X$legXshift -Y$legYshift -B0 -O -K >> $out.ps
echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".2", ($1-i+1)*n, i} }' |\
  gmt psxy -R -J -Sc.3 -C$COLORMAP -Wthin,black -O -K >> $out.ps
echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".35", ($1-i+1)*n, 14, 0, 0, "LM", "Tpl. "i} }' |\
  gmt pstext -R -J -V -O >> $out.ps


### Convert to PS to PDF + PNG

# 1. PS to PDF
gmt psconvert $out.ps -A -Tf

# 2. PS to PNG
#ps2raster $out.ps -A -Q -Tg -E150 # This looks ugly!
#rm ps2raster*

# 2. PDF to PNG
convert -density 150 -flatten -antialias +repage -border 4 -bordercolor White $out''.pdf $out''.png


### Clean up
rm $out.ps
rm $COLORMAP
rm gmt.conf

exit
