#!/bin/sh
# Plot overview of several sequences
# 
#source ~/.alias
#shopt -s expand_aliases
DIR=$1

out=$DIR/"locations_all_CH_"$(date "+%Y-%m-%d")

## GMT settings
gmt set PS_MEDIA a2
gmt set PS_PAGE_ORIENTATION landscape

gmt set MAP_FRAME_TYPE fancy+
gmt set MAP_DEFAULT_PEN black
gmt set FORMAT_GEO_MAP +D.
gmt set MAP_FRAME_WIDTH 3p

gmt set MAP_GRID_PEN_PRIMARY 0.1p

gmt set FONT_LABEL 12
gmt set FONT_ANNOT_PRIMARY 8
gmt set MAP_ANNOT_OFFSET_PRIMARY .1c
gmt set MAP_LABEL_OFFSET .4c


###################### MAP VIEW
# For a constant dimensions among sequences
#R=$(gmt gmtinfo -C $DIR/loc_catalog.dat | awk '{print "-R"$3+($4-$3)/2-0.025"/"$3+($4-$3)/2+0.025"/"$5+($6-$5)/2-0.019"/"$5+($6-$5)/2+0.019}')
# For an individual (tight) plot
R=$(awk '{print $2, $3, 0.05, 0.035}' $DIR/loc_catalog.dat | gmt gmtinfo -Sxy -I0.0001)

#psbasemap -JM320p $R -B0.05g0.01:"":/0.05g0.01:"":WnSe -K -P > $out.ps
gmt psbasemap -JM320p $R -B0.1g0.1WnSe -K -P > $out.ps

# The TOPO
#TOPO=topo.grd
TOPO=$DIR/srtm_ECOS.grd
TOPO_illu=$DIR/srtm_ECOSi.grd
TOPOSCALE=$DIR/heiner.cpt
# Prepare topography files (see /usr/share/gmt/dbase/grdraster.info)
#"SRTM30 e020n40"		"m"	-R-20/20/40/90		-I0.5m		P i 1 		0	none	W020N90.DEM B
#gmt grdraster 8 $R -G$TOPO -V
#gmt grdsample $TOPO -G$TOPO_TMP -I18c $VERBOSE
#gmt grdgradient $TOPO_TMP -A0 -G$TOPO_illu -Nt0.5 $VERBOSE

# Plot topography + data
#gmt grdimage $DATA_GRID $DEFAULT -JZ0.10i -C$COLORSCALE -I$TOPO_INTENS -E100 -Q -O -K >> $out.ps
#gmt grdimage $TOPO $R -J -C$TOPOSCALE  -O -K>> $out.ps

# Fuck the above and use the prepared one for ECOS
gmt grdimage $R -J $TOPO -I$TOPO_illu -C$TOPOSCALE -O -K >> $out.ps

#Plot coastlines
BOARDERS=-Na/0.8p  # a: all borders; 0.8p,-: dashed
#COAST=-W1/17/73/71
WATER=-Sblue
#RIVERS=-Ia/0.5p,blue  # 1: permanent major rivers
gmt pscoast $R -J -Df $BOARDERS $COAST $RIVERS $WATER -O -K >> $out.ps

# The catalog events
awk '$0!~/#/ {mag=$5; {if (mag < 1)mag=1} print $2, $3, 0.05*mag^2}' $DIR/loc_catalog.dat |\
	sort -k3nr |\
	gmt psxy -R -J -Sc -Wthick,red -O -K >> $out.ps
# (sorting to plot the smaller over the bigger)

# Plot the names of sequences
# 1. outline
awk '{print $1, $2, $3}' $DIR/loc_sequences.dat |\
	gmt pstext -R -J -F+f12,Helvetica,-=1.5p,white+jCM -D0p/16p -N -O -K >> $out.ps
# 2. colored
awk '{print $1, $2, $3}' $DIR/loc_sequences.dat |\
	gmt pstext -R -J -F+f12,Helvetica,red+jCM -D0p/16p -N -O >> $out.ps



### Convert to PS to PDF + PNG

# 1. PS to PDF
gmt psconvert $out.ps -A -Tf

# 2. PS to PNG
#ps2raster $out.ps -A -Q -Tg -E150 # This looks ugly!
#rm ps2raster*

# 2. PDF to PNG
convert -density 150 -flatten -antialias +repage -border 4 -bordercolor White $out''.pdf $out''.png


### Clean up
rm -f tmp*
rm $out.ps
rm $COLORMAP
rm gmt.conf

exit
