#!/bin/sh
# plot time line of EQ sequence

FILENAME=$1
DIR=$(dirname "$FILENAME")

numTEMPLATES=$2
STARTDATE=$3
ENDDATE=$4

minMag=$5
maxMag=$6

#minMag=-2.5
#maxMag=2.5

#minMag=-2.0
#maxMag=3.0

#TODO: Find optimal axis params AUTOMATICALLY
# For Histogram
maxDailyEQ=$7
HistTICK=$8   #=$(echo $maxDailyEQ | awk '{print int($1/10)}')
HistTICKminor=$(echo $HistTICK | awk '{print int($1/10)}')

# For cumulative line
numEQ=$9   #=$(wc -l $FILENAME | awk '{print $1*1.05}')
CumTICK=${10}
CumTICKminor=$(echo $CumTICK | awk '{print int($1/10)}')
#CumTICK=$(echo $numEQ | awk '{print int($1/10)}')

out=${11}


TITLE=""
#TITLE="Sion sequence 2015"
#TITLE="Sierre sequence 2015"

# Time span
RDate=`echo $STARTDATE $ENDDATE | awk '{print "-R"$1"T/"$2"T"}'`
numDays=$(echo $(( ( $(date -ud $ENDDATE +'%s') - $(date -ud $STARTDATE +'%s') )/60/60/24 )) )


# -- GMT settings

gmt set PS_MEDIA A3
gmt set PS_PAGE_ORIENTATION landscape

gmt set FONT_TITLE 24
gmt set FONT_ANNOT_PRIMARY 10
#gmt set FONT_ANNOT_PRIMARY +9p
gmt set FONT_ANNOT_SECONDARY 10
gmt set FONT_LABEL 14

gmt set MAP_TICK_LENGTH_PRIMARY 0.2c
gmt set MAP_TICK_LENGTH_SECONDARY 0.35c

gmt set FORMAT_DATE_MAP "o"  # Month name ('mm' for month number)
gmt set FORMAT_CLOCK_MAP "hh:mm"
gmt set TIME_UNIT h  # Used for time stepping in histogram
#gmt set FORMAT_TIME_PRIMARY_MAP Character
#gmt set FORMAT_TIME_SECONDARY_MAP abbreviated
gmt set TIME_WEEK_START Monday


# -- Define colors

colSED=120/120/120
#colSED=195/32/53  # (red)
colGEL=0/155/85
colALL=red

# Colormap of templates
COLORMAP=colormap.cpt
COLORTABLE=panoply  # panoply, rainbow, jet, cyclic, haxby, wysiwyg
gmt makecpt -C$COLORTABLE -M --COLOR_BACKGROUND=$colSED -T1/`echo $numTEMPLATES | awk '{print $1*1+1}'`/1 > $COLORMAP

# For WEB
#colSED=226/0/26  # (red)
#colALL=40/142/244 # (blue)
#gmt makecpt -Cgray -M --COLOR_FOREGROUND=$colALL -T-1/0/1 > $COLORMAP # Make all same color


# -- Create basemap

# For short periods (some days)
if [ $numDays -le 31 ] ; then
	# [p: days, s: month+year]
#	annotPrim=-Bpa1df1hg1d
#	annotSec=-Bsa1O
	annotX='-Bpxa1df1hg1d -Bsxa1O'
	annotHist=-Bg1d
	gmt set FORMAT_DATE_MAP "o yyyy" # Month + year

# For mid-term periods (some months up to a year)
elif [ $numDays -le 365 ] ; then
	# [p: months, s: year]; labeling weeks
#	annotPrim=-Bpa7Rf1dg1o
#	annotSec=-Bsa1O
	annotX='-Bpxa7Rf1dg1o -Bsxa1O'
	annotHist=-Bg1o
	gmt set FORMAT_DATE_MAP "o yy" # Month + year

# For long periods (1-2 years)
elif [ $numDays -le 730 ] ; then
	# [p: months, s: year]; ticking weeks
#	annotPrim=-Bpa7Rf1dg1o
#	annotSec=-Bsa1O
	annotX='-Bpxa1Of7Rg1o -Bsxa1Y'
	annotHist=-Bg1o
	gmt set FORMAT_TIME_PRIMARY_MAP abbreviated # Abbreviate primary axis (months)

# For very long periods (some years)
else
	# [p: months, s: year]
#	annotPrim=-Bpf1og1o
#	annotSec=-Bsa1Y
	annotX='-Bpxf1og1o -Bsxa1Y'
	annotHist=-B1Y
fi

gmt psbasemap -JX25T/10 $RDate/$minMag/$maxMag \
	$annotX+l" " -Bya1f.1+l"Magnitude [ML @-corr@-]" -BWeSn -K > $out.ps
#	$annotPrim:"":/a1f.1SWne:"Magnitude [ML @-corr@-]": $annotSec -K >> $out.ps


# -- Gaps

#$DIR/OTER2_gaps.sh $minMag $maxMag | gmt psxy -J -R -Wgrey -Ggrey -L -O -K >> $out.ps


# --Catalog events

awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_catalogALL.dat | sort -nrk2,2 |\
	gmt psxy -R -J -V -Sc -Wfatter,$colSED -O -K >> $out.ps

## SED catalog events
#awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_SEDcatalogALL.dat | sort -nrk2,2 |\
#	gmt psxy -R -J -V -Sc -Wfatter,$colSED -O -K >> $out.ps

## GEL catalog events
#awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_GELcatalogALL.dat | sort -nrk2,2 |\
#	gmt psxy -R -J -V -Sc -Wfat,$colGEL -O -K >> $out.ps

#  Catalog events as missed events (will be visible if not overplot by detection)
awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_catalogALL.dat | sort -nrk2,2 |\
	gmt psxy -R -J -V -Sc -Wthinnest,black -G$colSED -O -K >> $out.ps
#awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_SEDcatalogALL.dat | sort -nrk2,2 |\
#	gmt psxy -R -J -V -Sc -Wthinnest,black -G$colSED -O -K >> $out.ps
#awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_GELcatalogALL.dat | sort -nrk2,2 |\
#	gmt psxy -R -J -V -Sc -Wthinnest,black -G$colSED -O -K >> $out.ps


# -- Detections

## Variant 1: as is
#awk '{print $1, $3, substr($4,3), ($3+2)/7+.05}' $FILENAME | sort -nrk2,2 |\
#	gmt psxy -R -J -V -N -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K >> $out.ps
##	psxy -V -N -JX25/10 $RDate/-2/3 -Sc -Wthinnest,black -Gblue -P -K >> $out.ps

# Variant 2: with custom order
# Expl: As long as in file1 (NR==FNR), write $2 into array A with $1 as ID. If reading file2 and if ID in array ($4 in A), write out desired fields + array element for ID
awk 'NR==FNR{A[$1]=$2;next}
	($4 in A){print $1, $3, substr(A[$4],3), ($3+2)/7+.05}' $DIR/timeline_template_order.dat $FILENAME | sort -nrk2,2 |\
	gmt psxy -R -J -V -N -Sc -Wthinnest,black -C$COLORMAP -O -K >> $out.ps


# -- Plot templates separately (and their ranks in legend as numbers)

## Variant 1: as is
#awk '{print $1, $3, NR, ($3+2)/7+.05}' $DIR/regression_templates.dat |\
#	sort -nrk2,2 |\
#	gmt psxy -R -J -V -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K >> $out.ps
#awk '{print $1, $3, NR}' $DIR/regression_templates.dat |\
#	gmt pstext -R -J -F+f14,Helvetica,black+jCM -V -O -K >> $out.ps

# Variant 2: with custom order
awk 'NR==FNR{A[substr($1,3)]=$2;next}
	{print $1, $3, substr(A[FNR],3), ($3+2)/7+.05}' $DIR/timeline_template_order.dat $DIR/regression_templates.dat |\
	sort -nrk2,2 |\
	gmt psxy -R -J -V -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K >> $out.ps
awk 'NR==FNR{A[substr($1,3)]=$2;next}
	{print $1, $3, substr(A[FNR],3)}' $DIR/timeline_template_order.dat $DIR/regression_templates.dat |\
	gmt pstext -R -J -F+f14,Helvetica,black+jCM -V -O -K >> $out.ps


# -- Legend

#legXshift=0.0
#legYshift=0.0

legXshift=26.0
legYshift=0.0

#legXshift=21.5
#legYshift=1.5

legHeight=10

gmt psbasemap -R0/1/0/1 -JX2.5/$legHeight -X$legXshift -Y$legYshift -B0 -O -K >> $out.ps
echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".2", ($1-i+1)*n, i} }' |\
  gmt psxy -R -J -Sc.3 -C$COLORMAP -Wthin,black -O -K >> $out.ps

# Legend text - Variant 1: as is
#echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".35", ($1-i+1)*n, "Tpl. "i} }' |\
#  gmt pstext -R -J -F+f14,Helvetica,black+jLM -V -O -K >> $out.ps

# Legend text - Variant 2: from custom order
# Expl: Write the Legend Text into array A with template number as ID. Later, loop over template numbers
awk '{tpNum=substr($2,3); A[tpNum]=$3}
	 END{for (i=1;i<=numTEMPL;i++){print ".8", (numTEMPL-i+1)/(numTEMPL+1), A[i]} }' numTEMPL=$numTEMPLATES $DIR/timeline_template_order.dat |\
  gmt pstext -R -J -F+f10,Helvetica,black+jRM -V -O -K >> $out.ps


# -- Top plots

# Histogram
awk '$3>-3 { print $1 }' $FILENAME |\
  gmt pshistogram -JX25T/5 $RDate/0/$maxDailyEQ -Xf1i -Yf5.33i -W24 -fi0T \
  	$annotHist:."$TITLE":0/a$HistTICK''f$HistTICKminor:"@;black;No. events in 24 h@;;":nsW -Gblack -O -K >> $out.ps
# -Bpxa14Rf1dg1O -Bsx1O  -Bya20f5+l"@;blue;No. events in 24 h@;;" -BnsW+t""
# -F

# Cumulative line
awk '$3>-3 { print $1 }' $FILENAME |\
   gmt pshistogram -JX25T/5 $RDate/0/$numEQ -fi0T -F -B0/a$CumTICK''f$CumTICKminor:"@;"$colALL";cumulative no. EQs@;;":nsE -Lthicker,$colALL -S -Q -W1 -F -O -K >> $out.ps
# -Bpya5f1 -By+l"@;red;cumulative no. EQs@;;" -BE

# Cumulative line [special events]
awk '$3>-3 { print $2 }' $DIR/regression_catalogALL.dat |\
   gmt pshistogram -J -R -fi0T -F -Lthicker,$colSED -S -Q -W1 -F -O -K >> $out.ps
#     -Bpya5f1 -By+l"@;red;cumulative no. EQs@;;" -BE


## -- Extra: Basel Kopfdruck BS-1
#
#awk '{print $1, $2}' $DIR/Kopfdruck-Basel1_ALL_ownCompilation.csv |\
#   gmt psxy -JX25T/5 $RDate/0/10 -Y2.2i $annotHist/a2f1:"@;purple;wellhead pressure@;; [bar]":nsWe -diNaN -Wfat,purple -O -K >> $out.ps
#awk '{print $1, $3}' $DIR/Kopfdruck-Basel1_ALL_ownCompilation.csv |\
#   gmt psxy -J -R -B0/a2f1:"@;dodgerblue;manual reading@;; [bar]":nswE -diNaN -Sc.2 -Gdodgerblue -O >> $out.ps


# -- Convert to PS to PDF + PNG

# 1. PS to PDF
gmt psconvert $out.ps -Au -Tf -P

# 2. PS to PNG
#ps2raster $out.ps -A -Q -Tg -E150 # This looks ugly!
#rm ps2raster*

# 2. PDF to PNG
convert -density 100 -flatten -antialias -trim +repage -border 4 -bordercolor White $out.pdf $out.png


# --- Clean up

rm $out.ps
#rm $out.pdf
rm $COLORMAP
rm gmt.conf

exit
