#!/bin/sh
# plot time line of EQ sequence


FILENAME=$1
DIR=$(dirname "$FILENAME")
numTEMPLATES=$2
STARTDATE=$3
ENDDATE=$4

minMag=$5
maxMag=$6

minMag=-2.5
maxMag=2.5

#TODO: Find optimal axis params AUTOMATICALLY
# For Histogram
maxDailyEQ=$7
HistTICK=$8   #=$(echo $maxDailyEQ | awk '{print int($1/10)}')
HistTICKminor=$(echo $HistTICK | awk '{print int($1/10)}')

# For cumulative line
numEQ=$9   #=$(wc -l $FILENAME | awk '{print $1*1.05}')
CumTICK=$10
CumTICKminor=$(echo $CumTICK | awk '{print int($1/10)}')
#CumTICK=$(echo $numEQ | awk '{print int($1/10)}')

TITLE=""
#TITLE="Sion sequence 2015"
#TITLE="Sierre sequence 2015"

# Time span
RDate=`echo $STARTDATE $ENDDATE | awk '{print "-R"$1"T/"$2"T"}'`
numDays=$(echo $(( ( $(date -ud $ENDDATE +'%s') - $(date -ud $STARTDATE +'%s') )/60/60/24 )) )

## GMT settings
gmtset PAPER_MEDIA A3
gmtset PAGE_ORIENTATION landscape

gmtset HEADER_FONT_SIZE 24
gmtset ANNOT_FONT_SIZE_PRIMARY 10  ANNOT_FONT_SIZE_SECONDARY 10
gmtset LABEL_FONT_SIZE 14
#gmtset ANNOT_FONT_SIZE_PRIMARY +9p

gmtset TICK_LENGTH 0.1c

gmtset PLOT_DATE_FORMAT -o # "o yyyy"
gmtset PLOT_CLOCK_FORMAT "hh:mm"
gmtset TIME_UNIT h
#gmtset TIME_FORMAT_PRIMARY Character
#gmtset FORMAT_TIME_SECONDARY_MAP abbreviated
gmtset TIME_WEEK_START Monday



# Define colors
colSED=120/120/120
#colSED=195/32/53  # (red)
colGEL=0/155/85
colALL=red

# Colormap of templates
COLORMAP=colormap.cpt
COLORTABLE=panoply  # panoply, rainbow, jet, cyclic, haxby, wysiwyg
makecpt -C$COLORTABLE --COLOR_BACKGROUND=lightgray -T1/`echo $numTEMPLATES | awk '{print $1*1+1}'`/1 > $COLORMAP

# For WEB
#colSED=226/0/26  # (red)
#colALL=40/142/244 # (blue)
#makecpt -Cgray --COLOR_FOREGROUND=$colALL -T-1/0/1 > $COLORMAP # Make all same color


# Create map
# For short periods (some days)
if [ $numDays -le 31 ] ; then
	# [p: days, s: month+year]
	annotPrim=-Bpa1df1hg1d
	annotSec=-Bsa1O
	annotHist=-Bg1d
# For long periods (some months)
elif [ $numDays -le 365 ] ; then
	# [p: months, s: year]
	annotPrim=-Bpa7Rf1dg1o
	annotSec=-Bsa1O
	annotHist=-Bg1o
# For very long periods (some years)
else
	# [p: months, s: year]
	annotPrim=-Bpf1og1o
	annotSec=-Bsa1Y
	annotHist=-B0
fi

psbasemap -JX25T/10 $RDate/$minMag/$maxMag \
	$annotPrim:"":/a1f.1SWne:"Magnitude [ML @-corr@-]": $annotSec -K

#plot gaps
#psxy -JX25T/10 $RDate/0/1 -Wred -Glightred -L -K <<END
#2014-07-06T20:06:55.221 0
#2014-07-06T20:06:55.221 1
#2014-07-08T11:06:33.938 1
#2014-07-08T11:06:33.938 0
#END

# Plot catalog events
awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_catalogALL_reg-mag.dat | sort -nrk2,2 |\
	psxy -R -J -V -N -Sc -Wfatter,$colSED -O -K 
# Plot catalog events
awk '{print $2, $5, ($5+2)/7+.05}' $DIR/regression_GELcatalogALL_reg-mag.dat | sort -nrk2,2 |\
	psxy -R -J -V -N -Sc -Wfat,$colGEL -O -K 

## Detections
#awk '{print $1, $3, substr($4,3), ($3+2)/7+.05}' $FILENAME | sort -nrk2,2 |\
#	psxy -R -J -V -N -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K
##	psxy -V -N -JX25/10 $RDate/-2/3 -Sc -Wthinnest,black -Gblue -P -K
# Detections with custom order
# Expl: As long as in file1 (NR==FNR), write $2 into array A with $1 as ID. If reading file2 and if ID in array ($4 in A), write out desired fields + array element for ID
awk 'NR==FNR{A[$1]=$2;next}
	($4 in A){print $1, $3, substr(A[$4],3), ($3+2)/7+.05}' $DIR/timeline_template_order.dat $FILENAME | sort -nrk2,2 |\
	psxy -R -J -V -N -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K

## Plot templates again separately + numbers 
#awk '{print $1, $3, NR, ($3+2)/7+.05}' $DIR/regression_templates_reg-mag_episode.dat |\
#	sort -nrk2,2 |\
#	psxy -R -J -V -N -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K
#awk '{print $1, $3, 14, 0, 0, "CM", NR}' $DIR/regression_templates_reg-mag_episode.dat |\
#	pstext -R -J -V -O -K

# Plot some "special" events
#awk '{print $1, $3, substr($4,3), ($3+2)/7+.05}' detections/special.dat | sort -nrk2,2 |\
#  psxy -V -N -J -R -Sc -Wthickest,forestgreen -C$COLORMAP -O -K


# Legend
#legXshift=0.0
#legYshift=0.0
legXshift=26.0
legYshift=0.0
#legXshift=21.5
#legYshift=1.5
legHeight=10
psbasemap -R0/1/0/1 -JX2.5/$legHeight -X$legXshift -Y$legYshift -B0 -O -K
echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".2", ($1-i+1)*n, i} }' |\
  psxy -R -J -Sc.3 -C$COLORMAP -Wthin,black -O -K
#echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".35", ($1-i+1)*n, 14, 0, 0, "LM", "Tpl. "i} }' |\
#  pstext -R -J -V -O -K
# Use the text from the template order file
# Expl: As long as in file1 (NR==FNR), write the Legend Text into array A with template number as ID. Later, loop over template numbers
awk '{tpNum=substr($2,3); A[tpNum]=$3}
	 END{for (i=1;i<=NR;i++){print ".8", (NR-i+1)/(NR+1), 10, 0, 0, "RM", A[i]} }' $DIR/timeline_template_order.dat |\
  pstext -R -J -V -O -K

# Histogram
awk '$3>-3 { print $1 }' $FILENAME |\
  pshistogram -JX25T/5 $RDate/0/$maxDailyEQ -X$(echo 0 - $legXshift | bc) -Y$(echo 11.0 - $legYshift | bc) -W24 -fi0T \
  	$annotHist:."$TITLE":0/a$HistTICK''f$HistTICKminor:"@;black;No. events in 24 h@;;":nsW -Gblack -O -K
# -Bpxa14Rf1dg1O -Bsx1O  -Bya20f5+l"@;blue;No. events in 24 h@;;" -BnsW+t""
# -F

# Cumulative line

awk '$3>-3 { print $1 }' $FILENAME |\
   pshistogram -JX25T/5 $RDate/0/$numEQ -fi0T -F -B0/a$CumTICK''f$CumTICKminor:"@;"$colALL";cumulative no. EQs@;;":nsE -Lthicker,$colALL -S -Q -W1 -F -O -K
# -Bpya5f1 -By+l"@;red;cumulative no. EQs@;;" -BE

## Cumulative line [special events]
awk '$3>-3 { print $2 }' $DIR/regression_catalogALL_reg-mag_episode.dat |\
   pshistogram -JX25T/5 -R -fi0T -F -Lthicker,$colSED -S -Q -W1 -F -O -K
#     -Bpya5f1 -By+l"@;red;cumulative no. EQs@;;" -BE


#plot gaps
#psxy -JX25T/5 $RDate/0/1 -Wred -Glightred -L -O <<END
#2006-12-23T00:00:00.000 0
#2006-12-23T00:00:00.000 1
#2006-12-24T00:00:00.000 1
#2006-12-24T00:00:00.000 0
#END

rm $COLORMAP
