#!/bin/sh
# plot time line of EQ sequence


FILENAME=$1
numTEMPLATES=17
STARTDATE=$3
ENDDATE=$4

minMag=-2
maxMag=3

#TODO: Find optimal axis params AUTOMATICALLY
# For Histogram
maxDailyEQ=100
HistTICK=$(echo $maxDailyEQ | awk '{print int($1/10)}')
HistTICKminor=$(echo $HistTICK | awk '{print int($1/10)}')

# For cumulative line
numEQ=$(wc -l $FILENAME | awk '{print $1*1.05}')
CumTICK=1000
CumTICKminor=$(echo $CumTICK | awk '{print int($1/10)}')
#CumTICK=$(echo $numEQ | awk '{print int($1/10)}')

# Time span
RDate=`echo $STARTDATE $ENDDATE | awk '{print "-R"$1"T/"$2"T"}'`



## GMT settings
gmtset PAPER_MEDIA A4
gmtset PAGE_ORIENTATION landscape

#gmtset FONT_ANNOT_PRIMARY 12  FONT_ANNOT_SECONDARY 14 
#gmtset FONT_LABEL 14 

#gmtset ANNOT_FONT_SIZE_PRIMARY +9p
gmtset PLOT_DATE_FORMAT "o yy" # -o
gmtset PLOT_CLOCK_FORMAT "hh:mm"
#gmtset TIME_UNIT h
#gmtset TIME_FORMAT_PRIMARY Character
#gmtset FORMAT_TIME_SECONDARY_MAP abbreviated
gmtset TIME_WEEK_START Monday



# Colormap of templates
COLORMAP=colormap.cpt
COLORTABLE=wysiwyg  # panoply, rainbow, jet, cyclic, haxby, wysiwyg
makecpt -C$COLORTABLE --COLOR_BACKGROUND=lightgray -T1/`echo $numTEMPLATES | awk '{print $1+1}'`/1 > $COLORMAP


# Create map
psbasemap -JX20T/10 $RDate/$minMag/$maxMag \
	-Bpf1og1o:"":/a1f.1SWnE:"Magnitude [ML @-corr@-]": -Bsa1Y -K
# -Bpa1df1hg1d -Bsa1O [p: days, s: month+year] For short periods (some days)...
# -Bpa1of1og1o -Bsa1O [p: months, s: year] For long periods (some months)...
#    -Bpf1og1o -Bsa1Y [p: months, s: year] For very long periods (some years)...


#plot gaps
#psxy -JX25T/10 $RDate/0/1 -Wred -Glightred -L -K <<END
#2014-07-06T20:06:55.221 0
#2014-07-06T20:06:55.221 1
#2014-07-08T11:06:33.938 1
#2014-07-08T11:06:33.938 0
#END


# Template detection events
awk '$(NF)>=.00 {print $1, $3, substr($4,3), ($3+2)/7+.05}' $FILENAME | sort -nrk2,2 |\
  psxy -V -N -J -R -Sc -Wthinnest,black -Gblue -C$COLORMAP -O -K
#  psxy -V -N -JX25/10 $RDate/-2/3 -Sc -Wthinnest,black -Gblue -P -K

# Plot some "special" events
#awk '$(NF)>=.00 {print $1, $3, substr($4,3), ($3+2)/7+.05}' detections/special.dat | sort -nrk2,2 |\
#  psxy -V -N -J -R -Sc -Wthickest,forestgreen -C$COLORMAP -O -K

## SC3 events
#awk '$(NF)>=.00 {print $1, $5, substr($6,3), ($5+2)/7+.05}' $dir/dayplot/logA_SC3.dat | sort -nrk2,2 |\
#  psxy -V -N -JX25T/10 $RDate/0.0/4.0 -Sc -Wthickest,190/0/0 -C$COLORMAP -O -K 
##awk '{print $1, $NF, ($NF+2)/7+.05}' $dir/dayplot/DI_logA_ccmiss.dat | sort -nrk2,2 |\
##  psxy -V -N -JX25/10 $RDate/-2/3 -Sc -Wthicker,green -Gred -O 


# Legend
legXshift=0.0
legYshift=0.0
#legXshift=21.5
#legYshift=1.5
##psbasemap -R0/1/0/1 -JX2.5/8 -X$legXshift -Y$legYshift -B0 -O -K
#echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".2", ($1-i+1)*n, i} }' |\
#  psxy -R -JX -Sc.3 -C$COLORMAP -Wthin,black -O -K
#echo $numTEMPLATES | awk '{n=1/($1+1); for (i=1;i<=$1;i++){print ".35", ($1-i+1)*n, 14, 0, 0, "LM", "Tpl. "i} }' |\
#  pstext -R -JX -O -K -V


# Histogram
awk '$3>-3 { print $1 }' $FILENAME |\
  pshistogram -JX20T/5 $RDate/0/$maxDailyEQ -X$legXshift -Y$(echo 11.0 - $legYshift | bc) -W24 -fi0T -B0/a$HistTICK''f$HistTICKminor:"@;blue;No. events in 24 h@;;":nsW -Gblue -O -K
# -Bpxa14Rf1dg1O -Bsx1O  -Bya20f5+l"@;blue;No. events in 24 h@;;" -BnsW+t""
# -F

# Cumulative line
awk '$3>-3 { print $1 }' $FILENAME |\
   pshistogram -JX20T/5 $RDate/0/$numEQ -fi0T -F -B0/a$CumTICK''f$CumTICKminor:"@;red;cumulative no. EQs@;;":nsE -Lthicker,red -S -Q -W1 -F -O -K
# -Bpya5f1 -By+l"@;red;cumulative no. EQs@;;" -BE


#plot gaps
psxy -JX25T/5 $RDate/0/1 -Wred -Glightred -L -O <<END
#2014-07-06T20:06:55.221 0
#2014-07-06T20:06:55.221 1
#2014-07-08T11:06:33.938 1
#2014-07-08T11:06:33.938 0
END

rm $COLORMAP
